@@ -9,14 +9,12 @@ OpenTracing::Implementation::NoOp::ScopeManager - NoOp, so code won't break!
 Objects of this class implement the required methods of the
 L<OpenTracing::Interface::ScopeManager>,
 to be compliant during testing and allow applications to continue working
-without having to catch exceptions all the time.
+without having to catch acceptions all the time.
 
-None of the methods will do anything useful.
+None of the methods will do anything usefull.
 
 =cut
 
-our $VERSION = 'v0.72.1';
-
 
 
 use OpenTracing::Implementation::NoOp::Scope;
@@ -31,7 +29,9 @@ sub activate_span {
     OpenTracing::Implementation::NoOp::Scope->new( )
 }
 
-sub get_active_scope { return }
+sub get_active_scope {
+    OpenTracing::Implementation::NoOp::Scope->new( )
+}
 
 
 
